@@ -729,7 +729,7 @@ static
 int dhcdbd_run_dhclient( DHC_IF *d_if )
 {
     char **dhc_args, **dhc_envp, *xtra_arg=0L;
-    uint8_t n_args=11, arg;
+    uint8_t n_args=12, arg;
     DHC_IF *rel_if=0L;
     int i;
     sigset_t ss;
@@ -907,6 +907,10 @@ int dhcdbd_run_dhclient( DHC_IF *d_if )
 	  )return -1;
 	sprintf(dhc_args[arg], "%s%s%s", DHCDBD_DHCLIENT_PID_PFX, d_if->name, DHCDBD_DHCLIENT_PID_SFX);
 
+	if((dhc_args[++arg] = (char*)malloc( 3 )) == 0L)
+	    return -1;
+	strcpy(dhc_args[arg], "-q");
+
 	if((dhc_args[++arg] = (char*)malloc( 3 )) == 0L)
 	    return -1;
 	strcpy(dhc_args[arg], "-e");
@@ -987,9 +991,7 @@ int dhcdbd_run_dhclient( DHC_IF *d_if )
 	    if( i == 0 )
 		fcntl(i,F_SETFD,0L);
 	}
-	if( ((i = open("/dev/console",O_WRONLY)) != -1)
-	  ||((i = open("/dev/null",O_WRONLY)) != -1)
-	  )
+	if((i = open("/dev/null",O_WRONLY)) != -1)
 	{
 	    if( i != 1 )
 	    	if( dup2(i,1) == 1 )
@@ -1000,9 +1002,7 @@ int dhcdbd_run_dhclient( DHC_IF *d_if )
 	    if( i == 1 )
 		fcntl(i,F_SETFD,0L);
 	}
-	if( ((i = open("/dev/console",O_WRONLY)) != -1)
-	  ||((i = open("/dev/null",O_WRONLY)) != -1)
-	  )
+	if((i = open("/dev/null",O_WRONLY)) != -1)
 	{
 	    if( i != 2 )
 	    	if( dup2(i,2) == 2 )
@@ -2739,26 +2739,11 @@ int dhcdbd_run( D_BUS_TYPE bus )
     DBUS_SVC dbus;
     DHCO     dhco;
     struct   sigaction sa;
-    pid_t pid;
     char path[1024];
     int fd, l;
 
-    if( dhcdbd_daemonize )
-    {
-	if ( (pid = fork()) == -1 )
-	    return errno;
-	else
-	if (pid > 0)
-	    exit(0);
-	ioctl(0,TIOCNOTTY,0);
-	close(0);
-	close(1);
-	close(2);
-	open("/dev/null", O_RDONLY);
-	open("/dev/console",O_WRONLY);
-	open("/dev/console",O_WRONLY);
-	setsid();
-    }
+    if( dhcdbd_daemonize && (daemon(0, 0) == -1) )
+	return errno;
 
     openlog( "dhcdbd", LOG_NDELAY | LOG_CONS, LOG_USER );
 
